@@ -180,8 +180,9 @@ symbol such as 'variable-added.")
   "A regexp matching whitelisted non-standard symbol prefixes.")
 
 (defvar package-lint--allowed-prefix-mappings
-  '(("ox-" . ("org-"))
-    ("ob-" . ("org-")))
+  '(("ob-" . ("org-"))
+    ("ol-" . ("org-"))
+    ("ox-" . ("org-")))
   "Alist containing mappings of package prefixes to symbol prefixes.")
 
 (defun package-lint--main-file-p ()
@@ -875,8 +876,8 @@ DESC is a struct as returned by `package-buffer-info'."
     (when (and (string-match "[:/]" name)
                (not (string-match-p package-lint--sane-prefixes name)))
       (let ((match-pos (match-beginning 0)))
-        ;; As a special case, allow `/=' when at the end of a symbol.
-        (when (or (not (string-match (rx "/=" string-end) name))
+        ;; As a special case, allow `/=' or `/' when at the end of a symbol.
+        (when (or (not (string-match (rx "/" (optional "=") string-end) name))
                   (/= match-pos (match-beginning 0)))
           (goto-char position)
           (package-lint--error
@@ -914,7 +915,7 @@ Valid definition names are:
       (when position
         (goto-char position)
         (looking-at-p (rx (*? space) "(" (*? space)
-                          (or "defadvice" "cl-defmethod")
+                          (or "defadvice" "cl-defmethod" "define-advice")
                           symbol-end)))))
 
 (defun package-lint--check-defs-prefix (prefix definitions)
@@ -1058,7 +1059,7 @@ PREFIX is the package prefix."
 Lines consisting only of whitespace or empty comments are considered empty."
   (save-excursion
     (save-restriction
-      (let ((inhibit-changing-match-data t))
+      (save-match-data
         (narrow-to-region start end)
         (goto-char start)
         (while (and (looking-at "^[[:space:]]*;*[[:space:]]*$")
